# Kalkulator BMI
## BMI (Body Mass Index)
Body Mass Index atau BMI adalah suatu ukuran yang digunakan untuk menunjukkan kategori berat badan seseorang. Metode perhitungan ini awalnya dikembangkan pada abad 19 oleh Adolphe Quetelet [2]. Adapun istilah lain dalam menyebut BMI adalah indeks massa tubuh (IMT). 

## Cara menggunakannya
```
import program

if __name__ == '__main__':
    program.mulai()
```
